"use strict";

// src/index.ts
var import_html_validate3 = require("html-validate");

// package.json
var name = "html-validate-angular";
var peerDependencies = {
  "html-validate": "^8.10.0 || ^9.0.0"
};

// src/attribute.ts
var import_html_validate = require("html-validate");
var directives = [
  "checked",
  "class",
  "disabled",
  "href",
  "maxlength",
  "minlength",
  "pattern",
  "readonly",
  "required",
  "selected",
  "src",
  "style",
  "value"
];
var matchBinding = /^\[(attr\.)?([^\]]*)\]/;
var matchNgAttr = new RegExp(`^ng-(?:attr-(.*)|(${directives.join("|")}))$`);
function* generateDynamicAlias(attr, key) {
  yield attr;
  yield {
    ...attr,
    key,
    value: new import_html_validate.DynamicValue(attr.value),
    originalAttribute: attr.key
  };
}
function* processAttribute(attr) {
  const binding = matchBinding.exec(attr.key);
  if (binding) {
    yield* generateDynamicAlias(attr, binding[2]);
    return;
  }
  const ngAttr = matchNgAttr.exec(attr.key);
  if (ngAttr) {
    yield* generateDynamicAlias(attr, ngAttr[1] || ngAttr[2]);
    return;
  }
  if (typeof attr.value === "string" && /{{.*}}/.exec(attr.value)) {
    yield { ...attr, value: new import_html_validate.DynamicValue(attr.value) };
    return;
  }
  yield attr;
}

// src/element.ts
var import_html_validate2 = require("html-validate");
function isBound(node) {
  return node.hasAttribute("ng-bind") || node.hasAttribute("ng-bind-html") || node.hasAttribute("ng-bind-template") || node.hasAttribute("translate");
}
function isTranscluded(node) {
  return node.is("ng-transclude") || node.hasAttribute("ng-transclude");
}
function isPluralize(node) {
  return node.is("ng-pluralize") || node.hasAttribute("ng-pluralize");
}
function processElement(node) {
  if (isBound(node) || isTranscluded(node) || isPluralize(node)) {
    node.appendText(new import_html_validate2.DynamicValue(""), node.location);
  }
}

// src/utils/strip-templating.ts
function stripTemplating(str) {
  return str.replace(/{{(.*?)}}/g, (_, m) => {
    const filler = " ".repeat(m.length);
    return `{{${filler}}}`;
  });
}

// src/transform/transform.ts
function transform(source) {
  return {
    ...source,
    data: stripTemplating(source.data),
    originalData: source.data,
    hooks: {
      processAttribute,
      processElement
    }
  };
}

// src/transform/transform-html.ts
function angularTransformHTML(source) {
  return [transform(source)];
}
angularTransformHTML.api = 1;

// src/transform/transform-js.ts
var import_plugin_utils = require("@html-validate/plugin-utils");
function angularTransformJS(source) {
  const te = import_plugin_utils.TemplateExtractor.fromString(source.data, source.filename);
  const sources = te.extractObjectProperty("template");
  return sources.map(transform);
}
angularTransformJS.api = 1;

// src/transform/index.ts
var transformer = {
  html: angularTransformHTML,
  js: angularTransformJS
};
var transform_default = transformer;

// src/index.ts
var range = peerDependencies["html-validate"];
(0, import_html_validate3.compatibilityCheck)(name, range);
var plugin = {
  name,
  transformer: transform_default
};
var src_default = plugin;

// src/entry-cjs.ts
module.exports = src_default;
//# sourceMappingURL=index.cjs.map
